.. Orbit documentation master file, created by
   sphinx-quickstart on Thu Aug 20 13:19:36 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Orbit's Documentation!
=================================

.. toctree::
   :maxdepth: 1
   :caption: Basic
   :name: basic

   about
   installation
   tutorials/quick_start
   tutorials/model_estimations
   tutorials/pyro_basic

.. toctree::
   :maxdepth: 1
   :caption: Exponential Smoothing Models
   :name: exponential-smoothing-models

   tutorials/dlt
   tutorials/lgt
   tutorials/regression

.. toctree::
   :maxdepth: 1
   :caption: Multiple Seasonality Model

   tutorials/ktrlite

.. toctree::
   :maxdepth: 1
   :caption: Validation
   :name: validation

   tutorials/decompose_prediction
   tutorials/model_diagnostics
   tutorials/backtest

.. toctree::
   :maxdepth: 1
   :caption: Other Utilities
   :name: other-utilities

   tutorials/exploratory_data_analysis
   tutorials/utilities_simulation

.. toctree::
   :maxdepth: 1
   :caption: For Developers
   :name: for-developers

   tutorials/build_your_own_model
   modules
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
